Documentation
¶
Overview ¶
Package reporter contains functionality for creating reports and printing results of executed dnsbench.Benchmark.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func PrintReport ¶
func PrintReport(b *dnsbench.Benchmark, stats []*dnsbench.ResultStats, benchStart time.Time, benchDuration time.Duration) error
PrintReport prints formatted benchmark result to stdout, exports graphs and generates CSV output if configured. If there is a fatal error while printing report, an error is returned.
Types ¶
type BenchmarkResultStats ¶
type BenchmarkResultStats struct {
Codes map[int]int64
Qtypes map[string]int64
Hist *hdrhistogram.Histogram
Timings []dnsbench.Datapoint
Counters dnsbench.Counters
Errors []dnsbench.ErrorDatapoint
GroupedErrors map[string]int
AuthenticatedDomains map[string]struct{}
DoHStatusCodes map[int]int64
}
BenchmarkResultStats represents merged results of the dnsbench.Benchmark execution.
func Merge ¶
func Merge(b *dnsbench.Benchmark, stats []*dnsbench.ResultStats) BenchmarkResultStats
Merge takes results of the executed dnsbench.Benchmark and merges them.
Click to show internal directories.
Click to hide internal directories.